==> graph-api-0.21.4-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/graph/rev220720/graph/topology/GraphBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology;
import java.lang.Class;
import java.lang.NullPointerException;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.Edge;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.EdgeKey;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.Prefix;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.PrefixKey;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.Vertex;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.VertexKey;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 * Class that builds {@link Graph} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     Graph createGraph(int fooXyzzy, int barBaz) {
 *         return new GraphBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of Graph, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see Graph
 *
 */
@Generated("mdsal-binding-generator")
public class GraphBuilder {

    private Uint32 _asn;
    private Graph.DomainScope _domainScope;
    private Map<EdgeKey, Edge> _edge;
    private String _name;
    private Map<PrefixKey, Prefix> _prefix;
    private Map<VertexKey, Vertex> _vertex;
    private GraphKey key;


    Map<Class<? extends Augmentation<Graph>>, Augmentation<Graph>> augmentation = Map.of();

    /**
     * Construct an empty builder.
     */
    public GraphBuilder() {
        // No-op
    }

    
    

    /**
     * Construct a builder initialized with state from specified {@link Graph}.
     *
     * @param base Graph from which the builder should be initialized
     */
    public GraphBuilder(Graph base) {
        final var aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this.key = base.key();
        this._name = base.getName();
        this._asn = base.getAsn();
        this._domainScope = base.getDomainScope();
        this._edge = base.getEdge();
        this._prefix = base.getPrefix();
        this._vertex = base.getVertex();
    }



    /**
     * Return current value associated with the property corresponding to {@link Graph#key()}.
     *
     * @return current value
     */
    public GraphKey key() {
        return key;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getAsn()}.
     *
     * @return current value
     */
    public Uint32 getAsn() {
        return _asn;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getDomainScope()}.
     *
     * @return current value
     */
    public Graph.DomainScope getDomainScope() {
        return _domainScope;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getEdge()}.
     *
     * @return current value
     */
    public Map<EdgeKey, Edge> getEdge() {
        return _edge;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getName()}.
     *
     * @return current value
     */
    public String getName() {
        return _name;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getPrefix()}.
     *
     * @return current value
     */
    public Map<PrefixKey, Prefix> getPrefix() {
        return _prefix;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getVertex()}.
     *
     * @return current value
     */
    public Map<VertexKey, Vertex> getVertex() {
        return _vertex;
    }

    /**
     * Return the specified augmentation, if it is present in this builder.
     *
     * @param <E$$> augmentation type
     * @param augmentationType augmentation type class
     * @return Augmentation object from this builder, or {@code null} if not present
     * @throws NullPointerException if {@code augmentType} is {@code null}
     */
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Graph>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    /**
     * Set the key value corresponding to {@link Graph#key()} to the specified
     * value.
     *
     * @param key desired value
     * @return this builder
     */
    public GraphBuilder withKey(final GraphKey key) {
        this.key = key;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getAsn()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public GraphBuilder setAsn(final Uint32 value) {
        this._asn = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getDomainScope()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public GraphBuilder setDomainScope(final Graph.DomainScope value) {
        this._domainScope = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getEdge()} to the specified
     * value.
     *
     * @param values desired value
     * @return this builder
     */
    public GraphBuilder setEdge(final Map<EdgeKey, Edge> values) {
        this._edge = values;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getName()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public GraphBuilder setName(final String value) {
        this._name = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getPrefix()} to the specified
     * value.
     *
     * @param values desired value
     * @return this builder
     */
    public GraphBuilder setPrefix(final Map<PrefixKey, Prefix> values) {
        this._prefix = values;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getVertex()} to the specified
     * value.
     *
     * @param values desired value
     * @return this builder
     */
    public GraphBuilder setVertex(final Map<VertexKey, Vertex> values) {
        this._vertex = values;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public GraphBuilder addAugmentation(Augmentation<Graph> augmentation) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentation.implementedInterface(), augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public GraphBuilder removeAugmentation(Class<? extends Augmentation<Graph>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    /**
     * A new {@link Graph} instance.
     *
     * @return A new {@link Graph} instance.
     */
    public @NonNull Graph build() {
        return new GraphImpl(this);
    }

    private static final class GraphImpl
        extends AbstractAugmentable<Graph>
        implements Graph {
    
        private final Uint32 _asn;
        private final Graph.DomainScope _domainScope;
        private final Map<EdgeKey, Edge> _edge;
        private final String _name;
        private final Map<PrefixKey, Prefix> _prefix;
        private final Map<VertexKey, Vertex> _vertex;
        private final GraphKey key;
    
        GraphImpl(GraphBuilder base) {
            super(base.augmentation);
            if (base.key() != null) {
                this.key = base.key();
            } else {
                this.key = new GraphKey(base.getName());
            }
            this._name = key.getName();
            this._asn = base.getAsn();
            this._domainScope = base.getDomainScope();
            this._edge = CodeHelpers.emptyToNull(base.getEdge());
            this._prefix = CodeHelpers.emptyToNull(base.getPrefix());
            this._vertex = CodeHelpers.emptyToNull(base.getVertex());
        }
    
        @Override
        public GraphKey key() {
            return key;
        }
        
        @Override
        public Uint32 getAsn() {
            return _asn;
        }
        
        @Override
        public Graph.DomainScope getDomainScope() {
            return _domainScope;
        }
        
        @Override
        public Map<EdgeKey, Edge> getEdge() {
            return _edge;
        }
        
        @Override
        public String getName() {
            return _name;
        }
        
        @Override
        public Map<PrefixKey, Prefix> getPrefix() {
            return _prefix;
        }
        
        @Override
        public Map<VertexKey, Vertex> getVertex() {
            return _vertex;
        }
    
        
        
        
        
        
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = Graph.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return Graph.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return Graph.bindingToString(this);
        }
    }
}

==> graph-api-0.22.7-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/graph/rev220720/graph/topology/GraphBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology;
import java.lang.Class;
import java.lang.NullPointerException;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.Edge;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.EdgeKey;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.Prefix;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.PrefixKey;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.Vertex;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720.graph.topology.graph.VertexKey;
import org.opendaylight.yangtools.binding.Augmentation;
import org.opendaylight.yangtools.binding.lib.AbstractEntryObject;
import org.opendaylight.yangtools.binding.lib.CodeHelpers;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 * Class that builds {@link Graph} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     Graph createGraph(int fooXyzzy, int barBaz) {
 *         return new GraphBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of Graph, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see Graph
 *
 */
@Generated("mdsal-binding-generator")
public class GraphBuilder {

    private Uint32 _asn;
    private Graph.DomainScope _domainScope;
    private Map<EdgeKey, Edge> _edge;
    private String _name;
    private Map<PrefixKey, Prefix> _prefix;
    private Map<VertexKey, Vertex> _vertex;
    private GraphKey key;


    Map<Class<? extends Augmentation<Graph>>, Augmentation<Graph>> augmentation = Map.of();

    /**
     * Construct an empty builder.
     */
    public GraphBuilder() {
        // No-op
    }

    

    /**
     * Construct a builder initialized with state from specified {@link Graph}.
     *
     * @param base Graph from which the builder should be initialized
     */
    public GraphBuilder(final Graph base) {
        final var aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this.key = base.key();
        this._name = base.getName();
        this._asn = base.getAsn();
        this._domainScope = base.getDomainScope();
        this._edge = base.getEdge();
        this._prefix = base.getPrefix();
        this._vertex = base.getVertex();
    }



    /**
     * Return current value associated with the property corresponding to {@link Graph#key()}.
     *
     * @return current value
     */
    public GraphKey key() {
        return key;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getAsn()}.
     *
     * @return current value
     */
    public Uint32 getAsn() {
        return _asn;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getDomainScope()}.
     *
     * @return current value
     */
    public Graph.DomainScope getDomainScope() {
        return _domainScope;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getEdge()}.
     *
     * @return current value
     */
    public Map<EdgeKey, Edge> getEdge() {
        return _edge;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getName()}.
     *
     * @return current value
     */
    public String getName() {
        return _name;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getPrefix()}.
     *
     * @return current value
     */
    public Map<PrefixKey, Prefix> getPrefix() {
        return _prefix;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link Graph#getVertex()}.
     *
     * @return current value
     */
    public Map<VertexKey, Vertex> getVertex() {
        return _vertex;
    }

    /**
     * Return the specified augmentation, if it is present in this builder.
     *
     * @param <E$$> augmentation type
     * @param augmentationType augmentation type class
     * @return Augmentation object from this builder, or {@code null} if not present
     * @throws NullPointerException if {@code augmentType} is {@code null}
     */
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Graph>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    /**
     * Set the key value corresponding to {@link Graph#key()} to the specified
     * value.
     *
     * @param key desired value
     * @return this builder
     */
    public GraphBuilder withKey(final GraphKey key) {
        this.key = key;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getAsn()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public GraphBuilder setAsn(final Uint32 value) {
        this._asn = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getDomainScope()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public GraphBuilder setDomainScope(final Graph.DomainScope value) {
        this._domainScope = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getEdge()} to the specified
     * value.
     *
     * @param values desired value
     * @return this builder
     */
    public GraphBuilder setEdge(final Map<EdgeKey, Edge> values) {
        this._edge = values;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getName()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public GraphBuilder setName(final String value) {
        this._name = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getPrefix()} to the specified
     * value.
     *
     * @param values desired value
     * @return this builder
     */
    public GraphBuilder setPrefix(final Map<PrefixKey, Prefix> values) {
        this._prefix = values;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link Graph#getVertex()} to the specified
     * value.
     *
     * @param values desired value
     * @return this builder
     */
    public GraphBuilder setVertex(final Map<VertexKey, Vertex> values) {
        this._vertex = values;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public GraphBuilder addAugmentation(Augmentation<Graph> augmentation) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentation.implementedInterface(), augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public GraphBuilder removeAugmentation(Class<? extends Augmentation<Graph>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    /**
     * A new {@link Graph} instance.
     *
     * @return A new {@link Graph} instance.
     */
    public @NonNull Graph build() {
        return new GraphImpl(this);
    }

    private static final class GraphImpl
        extends AbstractEntryObject<Graph, GraphKey>
        implements Graph {
    
        private final Uint32 _asn;
        private final Graph.DomainScope _domainScope;
        private final Map<EdgeKey, Edge> _edge;
        private final String _name;
        private final Map<PrefixKey, Prefix> _prefix;
        private final Map<VertexKey, Vertex> _vertex;
    
        GraphImpl(final GraphBuilder base) {
            super(base.augmentation, extractKey(base));
            final var key = key();
            this._name = key.getName();
            this._asn = base.getAsn();
            this._domainScope = base.getDomainScope();
            this._edge = CodeHelpers.emptyToNull(base.getEdge());
            this._prefix = CodeHelpers.emptyToNull(base.getPrefix());
            this._vertex = CodeHelpers.emptyToNull(base.getVertex());
        }
        
        private static @NonNull GraphKey extractKey(final GraphBuilder base) {
            final var key = base.key();
            return key != null ? key
                : new GraphKey(base.getName());
        }
    
        @Override
        public Uint32 getAsn() {
            return _asn;
        }
        
        @Override
        public Graph.DomainScope getDomainScope() {
            return _domainScope;
        }
        
        @Override
        public Map<EdgeKey, Edge> getEdge() {
            return _edge;
        }
        
        @Override
        public String getName() {
            return _name;
        }
        
        @Override
        public Map<PrefixKey, Prefix> getPrefix() {
            return _prefix;
        }
        
        @Override
        public Map<VertexKey, Vertex> getVertex() {
            return _vertex;
        }
    
        
        
        
        
        
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = Graph.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return Graph.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return Graph.bindingToString(this);
        }
    }
}
